summaryrefslogtreecommitdiffstats
path: root/loader
diff options
context:
space:
mode:
authorAdam Jackson <ajax@redhat.com>2009-05-14 17:15:17 -0400
committerAdam Jackson <ajax@redhat.com>2009-05-14 17:19:15 -0400
commit8d84372beeeed6e31e9cd8a6563bdfaf4d72546b (patch)
tree7289300870897c25c713ce986f1e5856a65f60ee /loader
parentb3774e962c6ba1f732f2906a3d0459037818dfb7 (diff)
downloadanaconda-8d84372beeeed6e31e9cd8a6563bdfaf4d72546b.tar.gz
anaconda-8d84372beeeed6e31e9cd8a6563bdfaf4d72546b.tar.xz
anaconda-8d84372beeeed6e31e9cd8a6563bdfaf4d72546b.zip
loader: Mount /tmp as tmpfs not ramfs so we can swap it out
Diffstat (limited to 'loader')
-rw-r--r--loader/init.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/loader/init.c b/loader/init.c
index feb9c5545..cc4ca689a 100644
--- a/loader/init.c
+++ b/loader/init.c
@@ -665,15 +665,15 @@ int main(int argc, char **argv) {
}
printf("done\n");
/* we want our /tmp to be ramfs, but we also want to let people hack
* their initrds to add things like a ks.cfg, so this has to be a little
* tricky */
if (!testing) {
rename("/tmp", "/oldtmp");
mkdir("/tmp", 0755);
- printf("mounting /tmp as ramfs... ");
- if (mount("none", "/tmp", "ramfs", 0, NULL))
+ printf("mounting /tmp as tmpfs... ");
+ if (mount("none", "/tmp", "tmpfs", 0, NULL))
fatal_error(1);
printf("done\n");
@@ -665,15 +665,15 @@ int main(int argc, char **argv) {
}
printf("done\n");
- /* we want our /tmp to be ramfs, but we also want to let people hack
+ /* we want our /tmp to be tmpfs, but we also want to let people hack
* their initrds to add things like a ks.cfg, so this has to be a little
* tricky */